==============
Sphinx-Gallery
==============

.. image:: https://travis-ci.org/sphinx-gallery/sphinx-gallery.svg?branch=master
    :target: https://travis-ci.org/sphinx-gallery/sphinx-gallery

.. image::     https://ci.appveyor.com/api/projects/status/github/sphinx-gallery/sphinx-gallery?branch=master&svg=true
    :target: https://ci.appveyor.com/project/sphinx-gallery/sphinx-gallery/history

.. image:: https://zenodo.org/badge/25860190.svg
    :target: https://zenodo.org/badge/latestdoi/25860190


A Sphinx extension that builds an HTML version of any Python
script and puts it into an examples gallery.

.. image:: doc/_static/demo.png
   :width: 80%
   :alt: A demo of a gallery generated by Sphinx-Gallery

Who uses Sphinx-Gallery
=======================

* `Sphinx-Gallery <https://sphinx-gallery.github.io/auto_examples/index.html>`_
* `Scikit-learn <http://scikit-learn.org/dev/auto_examples/index.html>`_
* `Nilearn <https://nilearn.github.io/auto_examples/index.html>`_
* `MNE-python <https://www.martinos.org/mne/stable/auto_examples/index.html>`_
* `PyStruct <https://pystruct.github.io/auto_examples/index.html>`_
* `GIMLi <http://www.pygimli.org/_examples_auto/index.html>`_
* `Nestle <https://kbarbary.github.io/nestle/examples/index.html>`_
* `pyRiemann <https://pyriemann.readthedocs.io/en/latest/index.html>`_
* `scikit-image <http://scikit-image.org/docs/dev/auto_examples/>`_
* `Astropy <http://docs.astropy.org/en/stable/generated/examples/index.html>`_
* `SunPy <http://docs.sunpy.org/en/stable/generated/gallery/index.html>`_
* `PySurfer <https://pysurfer.github.io/>`_
* `Matplotlib <https://matplotlib.org/index.html>`_ `Examples <https://matplotlib.org/gallery/index.html>`_ and `Tutorials  <https://matplotlib.org/tutorials/index.html>`__
* `PyTorch tutorials <http://pytorch.org/tutorials>`_
* `Cartopy <http://scitools.org.uk/cartopy/docs/latest/gallery/>`_
* `PyVista <https://docs.pyvista.org/examples/>`_
* `SimPEG <http://docs.simpeg.xyz/content/examples/>`_
* `PlasmaPy <http://docs.plasmapy.org/en/latest/auto_examples/>`_
* `Fury <http://fury.gl/latest/auto_examples/index.html>`_

.. installation-begin-content

Installation
============

Install via ``pip``
-------------------

You can do a direct install via pip by using:

.. code-block:: bash

    $ pip install sphinx-gallery

Sphinx-Gallery will not manage its dependencies when installing, thus
you are required to install them manually. Our minimal dependency
is:

* Sphinx >= 1.8.3

Sphinx-Gallery has also support for packages like:

* Matplotlib
* Seaborn
* Mayavi

For much of this functionality, you will need ``pillow``. We also recommend
installing system ``optipng`` binaries to reduce the file sizes of the
generated PNG files.

Install as a Sphinx-gallery developer
-------------------------------------

You can get the latest development source from our `Github repository
<https://github.com/sphinx-gallery/sphinx-gallery>`_. You need
``setuptools`` installed in your system to install Sphinx-Gallery. For example,
you can do:

.. code-block:: console

    $ git clone https://github.com/sphinx-gallery/sphinx-gallery
    $ cd sphinx-gallery
    $ pip install -r dev-requirements.txt
    $ pip install -e .

.. installation-end-content

Citation
========

If you would like to cite Sphinx-Gallery you can do so using our `Zenodo
deposit <https://zenodo.org/record/3838216>`_.
